@@ -1,17 +1,18 @@
+{-# LANGUAGE CPP #-}
 -- |
 -- Stability: stable
 --
 -- Hspec is a testing framework for Haskell.
 --
 -- This is the library reference for Hspec.
--- The <http://hspec.github.io/ User's Manual> contains more in-depth
+-- The <https://hspec.github.io/ User's Manual> contains more in-depth
 -- documentation.
 module Test.Hspec (
 -- * Types
   Spec
 , SpecWith
-, Arg
 , Example
+, Arg
 
 -- * Setting expectations
 , module Test.Hspec.Expectations
@@ -23,6 +24,7 @@ module Test.Hspec (
 , context
 , example
 , parallel
+, sequential
 , runIO
 
 -- * Pending spec items
@@ -39,7 +41,7 @@ module Test.Hspec (
 , xdescribe
 , xcontext
 
--- * Focused spec items
+-- * Focused spec items #focus#
 -- |
 -- During a test run, when a spec contains /focused/ spec items, all other spec
 -- items are ignored.
@@ -49,6 +51,7 @@ module Test.Hspec (
 , fdescribe
 , fcontext
 
+#ifdef ENABLE_SPEC_HOOKS
 -- * Hooks
 , ActionWith
 , before
@@ -56,6 +59,7 @@ module Test.Hspec (
 , beforeWith
 , beforeAll
 , beforeAll_
+, beforeAllWith
 , after
 , after_
 , afterAll
@@ -63,13 +67,21 @@ module Test.Hspec (
 , around
 , around_
 , aroundWith
+, aroundAll
+, aroundAll_
+, aroundAllWith
+, mapSubject
+, ignoreSubject
+#endif
 
 -- * Running a spec
 , hspec
 ) where
 
 import           Test.Hspec.Core.Spec
+#ifdef ENABLE_SPEC_HOOKS
 import           Test.Hspec.Core.Hooks
+#endif
 import           Test.Hspec.Runner
 import           Test.Hspec.Expectations
 
